@@ -1,5 +1,5 @@
 
-// $Id: proximapsync_form.js,v 1.10 2023/06/27 13:16:56 gilles Exp gilles $
+// $Id: proximapsync_form.js,v 1.14 2025/06/14 13:16:10 gilles Exp gilles $
 
 /*jslint browser: true*/ /*global  $*/
 
@@ -315,25 +315,11 @@ $(document).ready(
         return ;
     } ;
 
-    var refresh_imapsync_current = function refresh_imapsync_current(  )
-    {
-        if ( 
-            "imapsync.lamiral.infoX" === location.hostname 
-            ||
-            "lamiral.infoX"          === location.hostname 
-        )
-        {
-            $( "#imapsync_current" ).load( "imapsync_current.txt" ) ;
-        }
-    }
-
 
     var refreshLog = function refreshLog( xhr )
     {
         var eta_obj ;
         var eta_str ;
-
-        refresh_imapsync_current(  ) ;
         
         eta_obj = extract_eta( xhr ) ;
 
@@ -350,7 +336,7 @@ $(document).ready(
         }
         else
         {
-                eta_str = eta_obj.str + " (refresh every " + refresh_interval_s + " s)" ;
+                eta_str = eta_obj.str + " (refresh done every " + refresh_interval_s + " s)" ;
                 eta_str = eta_str.replace(/(\r\n|\n|\r)/gm, "") ; // trim newlines
                 //$("#tests").append( "refreshLog  eta_str: " + eta_str + "\n" ) ;
                 $( "#progress-txt" ).text( eta_str ) ;
@@ -362,29 +348,29 @@ $(document).ready(
 
     var handleRun = function handleRun(xhr, timerRefreshLog)
     {
-
+        const time = new Date();
         $("#console").text(
             "Status: " + xhr.status + " " + xhr.statusText + "\n"
-            + "State: " + readyStateStr[xhr.readyState] + "\n" ) ;
-
-        if ( xhr.readyState === 4 ) {
-        // var headers = xhr.getAllResponseHeaders();
-        // $("#console").append(headers);
-        // $("#console").append("See the completed log\n");
-        clearInterval( timerRefreshLog ) ;
-        refreshLog( xhr ) ; // a last time
-        // back to enable state for next run
-        $("#bt-sync").prop("disabled", false) ;
-        
-        refresh_imapsync_current(  ) ;
+            + "State: " + readyStateStr[xhr.readyState] + "\n" 
+            + "Time: " + time + "\n" 
+            ) ;
 
+        if ( xhr.readyState === 4 )
+        {
+                // var headers = xhr.getAllResponseHeaders();
+                // $("#console").append(headers);
+                // $("#console").append("See the completed log\n");
+                clearInterval( timerRefreshLog ) ;
+                refreshLog( xhr ) ; // a last time
+                // back to enable state for next run
+                $("#bt-sync").prop("disabled", false) ;
         }
     }
 
     var imapsync = function imapsync()
     {
         var querystring = $("#form").serialize() ;
-        $("#abort").text("\n\n") ; // clean abort console
+        $("#abort").text("\n\n\n") ; // clean abort console
         $("#output").text("Here comes the log!\n\n") ;
 
         if ( "imap.gmail.com" === $("#host1").val() )
@@ -431,10 +417,12 @@ $(document).ready(
 
     var handleAbort = function handleAbort( xhr )
     {
-
+        const time = new Date() ;
         $( "#abort" ).text(
             "Status: " + xhr.status + " " + xhr.statusText + "\n"
-            + "State: " + readyStateStr[xhr.readyState] + "\n\n" ) ;
+            + "State: " + readyStateStr[xhr.readyState] + "\n"
+            + "Time: " + time + "\n"
+            ) ;
 
         if ( xhr.readyState === 4 )
         {
@@ -718,7 +706,6 @@ $(document).ready(
         $("#bt-sync").click(
             function ()
             {
-                refresh_imapsync_current(  ) ;
                 $("#bt-sync").prop("disabled", true) ;
                 $("#bt-abort").prop("disabled", false) ;
                 $("#progress-txt").text( "ETA: coming soon" ) ;
@@ -730,11 +717,9 @@ $(document).ready(
         $("#bt-abort").click(
             function ()
             {
-                refresh_imapsync_current(  ) ;
                 $("#bt-sync").prop("disabled", true);
                 $("#bt-abort").prop("disabled", true);
                 abort();
-                refresh_imapsync_current(  ) ;
             }
         );
 
@@ -769,23 +754,9 @@ $(document).ready(
             }
         ) ;
         
-        refresh_imapsync_current(  ) ;
 
-        if ( "imapsync.lamiral.infoX" === location.hostname )
-        {
-                $( "#local_bandwidth" ).collapse( "show" ) ;
-                $( "#local_status_dbmon" ).collapse( "show" ) ;
-                $( "#local_status_hetrix" ).collapse( "show" ) ;
-                $( "#imapsync_advice_hours" ).collapse( "show" ) ;
+        
         }
-        else if ( "lamiral.infoX" === location.hostname )
-        {
-                $( "#local_bandwidth" ).collapse( "show" ) ;
-                $( "#local_status_dbmon" ).collapse( "show" ) ;
-                $( "#local_status_hetrix" ).collapse( "show" ) ;
-                $( "#imapsync_advice_hours" ).collapse( "show" ) ;
-        }
-    }
 
         var tests_bilan = function tests_bilan( nb_attended_test )
         {
